pub struct GenerationOrchestrator { /* private fields */ }Expand description
Main orchestrator for generation.
Implementations
Sourceimpl GenerationOrchestrator
impl GenerationOrchestrator
Sourcepub fn new(config: GeneratorConfig) -> SynthResult<Self>
pub fn new(config: GeneratorConfig) -> SynthResult<Self>
Create a new orchestrator.
Sourcepub fn with_pause_flag(self, flag: Arc<AtomicBool>) -> Self
pub fn with_pause_flag(self, flag: Arc<AtomicBool>) -> Self
Set a pause flag that can be controlled externally (e.g., by a signal handler). When the flag is true, generation will pause until it becomes false.
Sourcepub fn generate_coa(&mut self) -> SynthResult<Arc<ChartOfAccounts>>
pub fn generate_coa(&mut self) -> SynthResult<Arc<ChartOfAccounts>>
Generate the chart of accounts.
Sourcepub fn calculate_total_transactions(&self) -> u64
pub fn calculate_total_transactions(&self) -> u64
Calculate total transactions to generate.
Sourcepub fn generate(&mut self) -> SynthResult<GenerationResult>
pub fn generate(&mut self) -> SynthResult<GenerationResult>
Run the generation.