pub struct StreamingOrchestrator { /* private fields */ }Expand description
Streaming orchestrator for real-time data generation.
Implementations
Sourceimpl StreamingOrchestrator
impl StreamingOrchestrator
Sourcepub fn new(config: StreamingOrchestratorConfig) -> Self
pub fn new(config: StreamingOrchestratorConfig) -> Self
Creates a new streaming orchestrator.
Sourcepub fn from_generator_config(config: GeneratorConfig) -> Self
pub fn from_generator_config(config: GeneratorConfig) -> Self
Creates a streaming orchestrator from generator config with defaults.
Sourcepub fn stream(
&self,
) -> SynthResult<(StreamReceiver<GeneratedItem>, Arc<StreamControl>)>
pub fn stream( &self, ) -> SynthResult<(StreamReceiver<GeneratedItem>, Arc<StreamControl>)>
Starts streaming generation.
Returns a receiver for stream events and a control handle.
Sourcepub fn stats(&self) -> StreamingOrchestratorStats
pub fn stats(&self) -> StreamingOrchestratorStats
Returns the orchestrator configuration stats.